The Oasys.THIS package allows Python scripts to control the Oasys LS-DYNA Environment
software `T/HIS <https://www.oasys-software.com/dyna/software/t-his/>`_.

Basic information
-----------------

The module uses gRPC to communicate with the T/HIS executable using the `Oasys.gRPC <https://pypi.org/project/Oasys.gRPC/>`_ module.


More information
----------------

* To see the Oasys Python API manual: 
  https://help.oasys-software.com/articles/py_api-21-0

* To see an introduction to this module: 
  https://help.oasys-software.com/articles/py_api-21-0/t-his

* To access all classes and functions of this module:
  https://www.oasys-software.com/dyna/sphinx/21.0/T-HIS

* For more details on the Oasys LS-DYNA environment software see:

  * Website: `https://www.oasys-software.com/dyna/software/ <https://www.oasys-software.com/dyna/software/>`_
  * Linkedin: `https://www.linkedin.com/company/oasys-ltd-software/ <https://www.linkedin.com/company/oasys-ltd-software/>`_
  * YouTube: `https://www.youtube.com/c/OasysLtd <https://www.youtube.com/c/OasysLtd>`_
  * Email: `dyna.support@arup.com <mailto:dyna.support@arup.com>`_
